admin

package
v1.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package admin 提供管理后台功能

Index

Constants

const (
	AdminRequired          = "未经授权访问"
	TokenAdminRequired     = "该访问令牌没有管理员权限,无法访问管理端点" //nolint:gosec // false positive: this is an error message, not hardcoded credentials
	InvalidAuthSourceID    = "认证源 ID 无效"
	InvalidCursorParam     = "无效的 cursor 参数"
	InvalidTaskExecutionID = "无效的任务执行记录 ID"
)

管理后台错误消息常量

Variables

This section is empty.

Functions

func LoginAdminRequired

func LoginAdminRequired() gin.HandlerFunc

LoginAdminRequired 返回管理员权限校验中间件

Types

This section is empty.

Directories

Path Synopsis
Package auth_source 提供认证源管理功能
Package auth_source 提供认证源管理功能
Package cache provides HTTP handlers for managing disk cache.
Package cache provides HTTP handlers for managing disk cache.
Package db_manage provides router handlers for managing database tables, overview information, and executing custom SQL queries.
Package db_manage provides router handlers for managing database tables, overview information, and executing custom SQL queries.
Package logs 提供日志查询与分析功能
Package logs 提供日志查询与分析功能
Package push defines push notification HTTP routes, background tasks, and events.
Package push defines push notification HTTP routes, background tasks, and events.
custom_events
Package custom_events defines custom push notification events.
Package custom_events defines custom push notification events.
Package status 提供系统状态查询接口
Package status 提供系统状态查询接口
Package system_config 提供系统配置管理功能
Package system_config 提供系统配置管理功能
Package task 提供任务管理接口
Package task 提供任务管理接口
Package template 提供模板管理功能
Package template 提供模板管理功能
Package updater manages GitHub Release checks and in-place application upgrades.
Package updater manages GitHub Release checks and in-place application upgrades.
Package user 提供用户管理功能
Package user 提供用户管理功能

Jump to