Documentation
¶
Overview ¶
Package util provides upload media helpers and image utilities.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CompressImageToWebP ¶
CompressImageToWebP decodes an image from srcReader and encodes it into WebP format using the specified quality (low -> 60, medium -> 75, high -> 85).
func IsArchiveExtension ¶
IsArchiveExtension reports whether ext is a common archive format.
func IsDocumentExtension ¶
IsDocumentExtension reports whether ext is a common document format.
func IsImageExtension ¶
IsImageExtension reports whether ext is a common image format.
func NormalizeImageQuality ¶
NormalizeImageQuality normalizes the requested image quality query parameter.
func ValidateS3Key ¶
ValidateS3Key validates an S3 object key for safety.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.